# Generated by Django 4.1.3 on 2022-12-26 04:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djf_surveys", "0010_model_translation"),
    ]

    operations = [
        migrations.AlterField(
            model_name="question",
            name="key",
            field=models.CharField(
                blank=True,
                help_text="Unique key for this question, fill in the blank if you want to use for automatic generation.",
                max_length=225,
                null=True,
                unique=True,
                verbose_name="key",
            ),
        ),
    ]



from djf_surveys import app_settings
from djf_surveys.utils import get_type_field


def surveys_context(request):
    context = {
        'get_master_template': app_settings.SURVEY_MASTER_TEMPLATE,
        'chart_js_src': app_settings.CHART_JS_SRC,
        'get_type_field': get_type_field
    }
    return context



from django.test import TestCase
from django.core.exceptions import ValidationError
from djf_surveys.validators import validate_rating


class ValidationForm(TestCase):
    def test_validate_rating(self):
        with self.assertRaises(ValidationError):
            validate_rating(0)

        with self.assertRaises(ValidationError):
            validate_rating(100)

        validate_rating(2)



from django import forms
from django.utils.translation import gettext_lazy as _
from djf_surveys.models import Question
from djf_surveys.widgets import InlineChoiceField


class QuestionForm(forms.ModelForm):
    
    class Meta:
        model = Question
        fields = ['label', 'key', 'help_text', 'required']


class QuestionWithChoicesForm(forms.ModelForm):
    
    class Meta:
        model = Question
        fields = ['label', 'key', 'choices', 'help_text', 'required']
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['choices'].widget = InlineChoiceField()
        self.fields['choices'].help_text = _("Click Button Add to adding choice")



# Generated by Django 2.2.24 on 2022-08-03 02:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djf_surveys', '0008_auto_20220721_0935'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='answer',
            options={'ordering': ['question__ordering']},
        ),
        migrations.AlterModelOptions(
            name='question',
            options={'ordering': ['ordering']},
        ),
        migrations.AddField(
            model_name='question',
            name='key',
            field=models.CharField(blank=True, help_text='unique key for this question, fill in the blank if you want to generate automatically', max_length=225, null=True, unique=True),
        ),
    ]
